/**
 * Java Management Service Query API
 * API for the Java Management Service. Use this API to view and manage Fleets.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { JavaManagementServiceWaiter } from "./javamanagementservice-waiter";
export declare enum JavaManagementServiceApiKeys {
}
export declare class JavaManagementServiceClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": JavaManagementServiceWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new JavaManagementServiceWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): JavaManagementServiceWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): JavaManagementServiceWaiter;
    /**
     * Move a specified Fleet into the compartment identified in the POST form. When provided, If-Match is checked against ETag values of the resource.
     *
     * @param ChangeFleetCompartmentRequest
     * @return ChangeFleetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/ChangeFleetCompartment.ts.html |here} to see how to use ChangeFleetCompartment API.
     */
    changeFleetCompartment(changeFleetCompartmentRequest: requests.ChangeFleetCompartmentRequest): Promise<responses.ChangeFleetCompartmentResponse>;
    /**
     * Create a new Fleet using the information provided.
     *
     * @param CreateFleetRequest
     * @return CreateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/CreateFleet.ts.html |here} to see how to use CreateFleet API.
     */
    createFleet(createFleetRequest: requests.CreateFleetRequest): Promise<responses.CreateFleetResponse>;
    /**
     * Deletes the Fleet specified by an identifier.
     * @param DeleteFleetRequest
     * @return DeleteFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/DeleteFleet.ts.html |here} to see how to use DeleteFleet API.
     */
    deleteFleet(deleteFleetRequest: requests.DeleteFleetRequest): Promise<responses.DeleteFleetResponse>;
    /**
     * Retrieve a Fleet with the specified identifier.
     * @param GetFleetRequest
     * @return GetFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/GetFleet.ts.html |here} to see how to use GetFleet API.
     */
    getFleet(getFleetRequest: requests.GetFleetRequest): Promise<responses.GetFleetResponse>;
    /**
     * Retrieve a Fleet Agent Configuration for the specified Fleet.
     * @param GetFleetAgentConfigurationRequest
     * @return GetFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/GetFleetAgentConfiguration.ts.html |here} to see how to use GetFleetAgentConfiguration API.
     */
    getFleetAgentConfiguration(getFleetAgentConfigurationRequest: requests.GetFleetAgentConfigurationRequest): Promise<responses.GetFleetAgentConfigurationResponse>;
    /**
     * Retrieve the details of a work request with the specified ID.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of all the Fleets contained by a compartment.
     *
     * @param ListFleetsRequest
     * @return ListFleetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/ListFleets.ts.html |here} to see how to use ListFleets API.
     */
    listFleets(listFleetsRequest: requests.ListFleetsRequest): Promise<responses.ListFleetsResponse>;
    /**
     * Retrieve a (paginated) list of errors for a specified work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieve a (paginated) list of logs for a specified work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List the work requests in a compartment.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * List application usage in a specified Fleet filtered by form parameters.
     * @param RequestSummarizedApplicationUsageRequest
     * @return RequestSummarizedApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/RequestSummarizedApplicationUsage.ts.html |here} to see how to use RequestSummarizedApplicationUsage API.
     */
    requestSummarizedApplicationUsage(requestSummarizedApplicationUsageRequest: requests.RequestSummarizedApplicationUsageRequest): Promise<responses.RequestSummarizedApplicationUsageResponse>;
    /**
     * List Java installation usage in a specified Fleet filtered by form parameters.
     * @param RequestSummarizedInstallationUsageRequest
     * @return RequestSummarizedInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/RequestSummarizedInstallationUsage.ts.html |here} to see how to use RequestSummarizedInstallationUsage API.
     */
    requestSummarizedInstallationUsage(requestSummarizedInstallationUsageRequest: requests.RequestSummarizedInstallationUsageRequest): Promise<responses.RequestSummarizedInstallationUsageResponse>;
    /**
     * List Java Runtime usage in a specified Fleet filtered by form parameters.
     * @param RequestSummarizedJreUsageRequest
     * @return RequestSummarizedJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/RequestSummarizedJreUsage.ts.html |here} to see how to use RequestSummarizedJreUsage API.
     */
    requestSummarizedJreUsage(requestSummarizedJreUsageRequest: requests.RequestSummarizedJreUsageRequest): Promise<responses.RequestSummarizedJreUsageResponse>;
    /**
     * List managed instance usage in a specified Fleet filtered by form parameters.
     * @param RequestSummarizedManagedInstanceUsageRequest
     * @return RequestSummarizedManagedInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/RequestSummarizedManagedInstanceUsage.ts.html |here} to see how to use RequestSummarizedManagedInstanceUsage API.
     */
    requestSummarizedManagedInstanceUsage(requestSummarizedManagedInstanceUsageRequest: requests.RequestSummarizedManagedInstanceUsageRequest): Promise<responses.RequestSummarizedManagedInstanceUsageResponse>;
    /**
     * List application usage in a Fleet filtered by query parameters.
     * @param SummarizeApplicationUsageRequest
     * @return SummarizeApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/SummarizeApplicationUsage.ts.html |here} to see how to use SummarizeApplicationUsage API.
     */
    summarizeApplicationUsage(summarizeApplicationUsageRequest: requests.SummarizeApplicationUsageRequest): Promise<responses.SummarizeApplicationUsageResponse>;
    /**
     * List Java installation usage in a Fleet filtered by query parameters.
     * @param SummarizeInstallationUsageRequest
     * @return SummarizeInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/SummarizeInstallationUsage.ts.html |here} to see how to use SummarizeInstallationUsage API.
     */
    summarizeInstallationUsage(summarizeInstallationUsageRequest: requests.SummarizeInstallationUsageRequest): Promise<responses.SummarizeInstallationUsageResponse>;
    /**
     * List Java Runtime usage in a specified Fleet filtered by query parameters.
     * @param SummarizeJreUsageRequest
     * @return SummarizeJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/SummarizeJreUsage.ts.html |here} to see how to use SummarizeJreUsage API.
     */
    summarizeJreUsage(summarizeJreUsageRequest: requests.SummarizeJreUsageRequest): Promise<responses.SummarizeJreUsageResponse>;
    /**
     * List managed instance usage in a Fleet filtered by query parameters.
     * @param SummarizeManagedInstanceUsageRequest
     * @return SummarizeManagedInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/SummarizeManagedInstanceUsage.ts.html |here} to see how to use SummarizeManagedInstanceUsage API.
     */
    summarizeManagedInstanceUsage(summarizeManagedInstanceUsageRequest: requests.SummarizeManagedInstanceUsageRequest): Promise<responses.SummarizeManagedInstanceUsageResponse>;
    /**
     * Update the Fleet specified by an identifier.
     * @param UpdateFleetRequest
     * @return UpdateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/UpdateFleet.ts.html |here} to see how to use UpdateFleet API.
     */
    updateFleet(updateFleetRequest: requests.UpdateFleetRequest): Promise<responses.UpdateFleetResponse>;
    /**
     * Update the Fleet Agent Configuration for the specified Fleet.
     * @param UpdateFleetAgentConfigurationRequest
     * @return UpdateFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.2.1/jms/UpdateFleetAgentConfiguration.ts.html |here} to see how to use UpdateFleetAgentConfiguration API.
     */
    updateFleetAgentConfiguration(updateFleetAgentConfigurationRequest: requests.UpdateFleetAgentConfigurationRequest): Promise<responses.UpdateFleetAgentConfigurationResponse>;
}
